import { className, mergeData, renderRules, validate } from '../../core/utils'
import { ICON } from '../../core/constants'
import ICONS from '../../core/icons'
import rules from './icon.rules'

const SIZES = [ 16, 18, 24, 36, 48 ]

export default {
  functional: true,
  inject: [
    'fela',
    'croudClassName'
  ],
  props: {
    name: {
      type: String,
      required: true
    },
    display: {
      type: String,
      default: 'block'
    },
    size: {
      type: Number,
      enums: SIZES,
      default: ICON.SMALL,
      validator: validate(SIZES)
    },
    color: {
      type: String
    }
  },
  render(h, ctx) {
    const { name, size, color } = ctx.props
    const classes = renderRules(ctx, rules)
    const path = ICONS[name]
    if (path) {
      return h('svg', mergeData(ctx, {
        class: className(ctx, 'icon', classes.svg),
        attrs: {
          xmlns: 'http://www.w3.org/2000/svg',
          viewBox: '0 0 24 24',
          height: size,
          width: size
        }
      }), [
        h('path', {
          attrs: {
            fill: color,
            d: path
          }
        })
      ])
    } else {
      return h('i', mergeData(ctx, {
        class: className(ctx, 'icon', classes.font)
      }), name.replace(/[\s-]/, '_').toLowerCase())
    }
  }
}
